@@ -5,7 +5,7 @@ import asyncio
 from pro_craft import AsyncIntel
 from pro_craft.utils import create_async_session
 from digital_life.utils import memoryCards2str
-from digital_life.models import MemoryCardGenerate,MemoryCardGenerateEasy, MemoryCard2, MemoryCard, MemoryCardScore, MemoryCards, Document, Chapter, MemoryCardGenerate2
+from digital_life.models import MemoryCardGenerate,MemoryCardGenerateEasy, MemoryCard2, MemoryCard, MemoryCardScore, MemoryCards, Document, Chapter, MemoryCardGenerate2, MemoryCardsGenerate
 from digital_life import super_log
 
 
@@ -143,7 +143,14 @@ class MemoryCardManager:
             chapters = chapters[:1]
         for i,chapter in enumerate(chapters):
             chapter.update(time_dicts[i])
-
+        
+        for chapter in chapters:
+            try:
+                MemoryCardsGenerate(memory_cards=[chapter])
+            except Exception as e:
+                super_log(f"{e}",'agenerate_memory_card Error')
+                chapter.update({"time":"----年--月--日"})
+                
         return chapters
 
 
