@@ -21,6 +21,11 @@ prompt_router = create_router(database_url=database_url,
               slave_database_url=database_url + "-test",
               model_name="doubao-1-5-pro-256k-250115",
               logger=logger)
+
+prompt_inner_router = create_router(database_url=database_url,
+              slave_database_url=database_url + "-test-inner",
+              model_name="doubao-1-5-pro-256k-250115",
+              logger=logger)
 app = FastAPI(
     title="LLM Service",
     description="Provides an OpenAI-compatible API for custom large language models.",
@@ -48,6 +53,7 @@ app.include_router(avatar_router, prefix="/digital_avatar")
 app.include_router(memory_card_router, prefix="/memory_card")
 app.include_router(recommended_router, prefix="/recommended")
 app.include_router(prompt_router, prefix="/prompt")
+app.include_router(prompt_inner_router, prefix="/prompt_inner")
 app.include_router(chat_router, prefix="/v1")
 app.include_router(biography_router)
 
